@@ -16,6 +16,9 @@ import copulae.datasets
 print("import: 'copulae.elliptical'")
 import copulae.elliptical
 
+print("import: 'copulae.empirical'")
+import copulae.empirical
+
 print("import: 'copulae.gof'")
 import copulae.gof
 
